scrollDown method
Scroll the terminal down by the specified number of rows.
Implementation
void scrollDown(int rows) => write(ansi.Term.scrollDown(rows));
Scroll the terminal down by the specified number of rows.
void scrollDown(int rows) => write(ansi.Term.scrollDown(rows));