KeyboardFlags class
Keyboard enhancement flags.
- Annotations
-
- @immutable
Constructors
- KeyboardFlags({bool disambiguateEscapeCodes = false, bool reportEventTypes = false, bool reportAlternateKeys = false, bool reportAllKeysAsEscapeCodes = false, bool reportAssociatedText = false})
-
Creates keyboard flags.
const
- KeyboardFlags.fromEvent(KeyboardEnhancementFlagsEvent event)
-
Creates from
KeyboardEnhancementFlagsEvent.factory
Properties
- disambiguateEscapeCodes → bool
-
Disambiguate escape codes.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- reportAllKeysAsEscapeCodes → bool
-
Report all keys as escape codes.
final
- reportAlternateKeys → bool
-
Report alternate keys.
final
- reportAssociatedText → bool
-
Report associated text.
final
- reportEventTypes → bool
-
Report event types (keyRepeat, keyRelease).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override