TrueColor class
Represents a true color with RGB values.
Constructors
Properties
- b ↔ int
-
The blue value.
latefinal
- g ↔ int
-
The green value.
latefinal
- hashCode → int
-
The hash code for this object.
no setteroverride
- hex ↔ String
-
String that represents the color in hexadecimal notation. ex: #DECAF0
latefinal
- profile → ProfileEnum
-
The profile of the color.
finalinherited
- r ↔ int
-
The red value.
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearColorCache(
) → void -
Clears the color cache.
inherited
-
convert(
ProfileEnum toProfile) → Color -
Converts a color from the current profile to another profile.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rgbDistance(
TrueColor color2) → double - Returns the distance between the current color and the passed one. The return a value is between 0 and 1. 0 means the colors are identical.
-
sequence(
{bool background = false}) → String -
Returns the TruColor sequence for the given color.
override
-
toAnsi16Color(
) → Ansi16Color - Convert TrueColor to Ansi16Color
-
toAnsi256Color(
) → Ansi256Color - Convert TrueColor to Ansi256Color
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override